==> haskell-regex-applicative-0.3.3-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-regex-applicative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-applicative
version: 0.3.3
id: regex-applicative-0.3.3-DxcXiGFOKNJAEyOISHX5JB
key: regex-applicative-0.3.3-DxcXiGFOKNJAEyOISHX5JB
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/regex-applicative
synopsis: Regex-based parsing with applicative interface
description:
    regex-applicative is a Haskell library for parsing using regular expressions.
    Parsers can be built using Applicative interface.
category: Text
author: Roman Cheplyaka
exposed: True
indefinite: False
exposed-modules:
    Text.Regex.Applicative Text.Regex.Applicative.Common
    Text.Regex.Applicative.Object Text.Regex.Applicative.Reference
    Text.Regex.Applicative.StateQueue
hidden-modules: Text.Regex.Applicative.Interface
                Text.Regex.Applicative.Types Text.Regex.Applicative.Compile
abi: e161b22e673551add88fc59f5452ce64
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/regex-applicative-0.3.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/regex-applicative-0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/regex-applicative-0.3.3
hs-libraries: HSregex-applicative-0.3.3-DxcXiGFOKNJAEyOISHX5JB
depends:
    base-4.10.1.0 containers-0.5.10.2 transformers-0.5.2.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
haddock-interfaces: /usr/share/doc/haskell-regex-applicative/html/regex-applicative.haddock
haddock-html: /usr/share/doc/haskell-regex-applicative/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-applicative-0.3.3-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-regex-applicative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-applicative
version: 0.3.3
id: regex-applicative-0.3.3-BvKJu2tlAhuf7di0MR5S2
key: regex-applicative-0.3.3-BvKJu2tlAhuf7di0MR5S2
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka
homepage: https://github.com/feuerbach/regex-applicative
synopsis: Regex-based parsing with applicative interface
description:
    regex-applicative is a Haskell library for parsing using regular expressions.
    Parsers can be built using Applicative interface.
category: Text
abi: fc4c77f9a65bbd31e3648a5ba5087989
exposed: True
exposed-modules:
    Text.Regex.Applicative Text.Regex.Applicative.Common
    Text.Regex.Applicative.Object Text.Regex.Applicative.Reference
    Text.Regex.Applicative.StateQueue
hidden-modules: Text.Regex.Applicative.Interface
                Text.Regex.Applicative.Types Text.Regex.Applicative.Compile
import-dirs: /usr/lib/ghc-8.4.2/site-local/regex-applicative-0.3.3
library-dirs: /usr/lib/ghc-8.4.2/site-local/regex-applicative-0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/regex-applicative-0.3.3
hs-libraries: HSregex-applicative-0.3.3-BvKJu2tlAhuf7di0MR5S2
depends:
    base-4.11.1.0 containers-0.5.11.0 transformers-0.5.5.0
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             containers-0.5.11.0=f8334bacfaf0e925ca7b24fb26fb2e66
             transformers-0.5.5.0=02be5c4dc3fdc926cf1b36bd484a25f8
haddock-interfaces: /usr/share/doc/haskell-regex-applicative/html/regex-applicative.haddock
haddock-html: /usr/share/doc/haskell-regex-applicative/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
